@@ -229,7 +229,7 @@ class DXFBase(object):
                      username=None, password=None,
                      actions=None, response=None,
                      authorization=None):
-        # pylint: disable=too-many-arguments
+        # pylint: disable=too-many-arguments,too-many-locals
         """
         Authenticate to the registry using a username and password,
         an authorization header or otherwise as the anonymous user.
@@ -285,8 +285,10 @@ class DXFBase(object):
             info = parsed['bearer']
             if actions and self._repo:
                 scope = 'repository:' + self._repo + ':' + ','.join(actions)
-            else:
+            elif 'scope' in info:
                 scope = info['scope']
+            else:
+                scope = ''
             url_parts = list(urlparse.urlparse(info['realm']))
             query = urlparse.parse_qs(url_parts[4])
             query.update({
@@ -302,7 +304,8 @@ class DXFBase(object):
                 _ignore_warnings(self)
                 r = self._sessions[0].get(auth_url, headers=headers, verify=self._tlsverify)
             _raise_for_status(r)
-            self.token = r.json()['token']
+            rjson = r.json()
+            self.token = rjson['access_token'] if 'access_token' in rjson else rjson['token']
             return self._token
 
         self._headers = headers
@@ -471,7 +474,7 @@ class DXF(DXFBase):
         :type digest: str
 
         :rtype: long
-        :returns: Whether the blob exists.
+        :returns: Size of the blob in bytes.
         """
         r = self._request('head', 'blobs/' + digest)
         return long(r.headers['content-length'])
@@ -499,7 +502,7 @@ class DXF(DXFBase):
             # registry as a blob store so to save us uploading extra blobs,
             # use the first layer.
             'config': {
-                'mediaType': 'application/octet-stream',
+                'mediaType': 'application/vnd.docker.container.image.v1+json',
                 'size': layers[0]['size'],
                 'digest': layers[0]['digest']
             },
@@ -743,6 +746,16 @@ class DXF(DXFBase):
                                 params={'n': batch_size})
         return it if iterate else list(it)
 
+    def api_version_check(self):
+        """
+        Performs API version check
+
+        :rtype: tuple
+        :returns: verson check response as a string (JSON) and requests.Response
+        """
+        r = self._base_request('get', '')
+        return r.content.decode('utf-8'), r
+
     @classmethod
     def from_base(cls, base, repo):
         """
